import keys
import httpx as h
import random
import json

from .template import ImageGet, ImageGetException

class ImageGetImmich(ImageGet):

    def __init__(self) -> None:
        headers = {
            "x-api-key": keys.immich_api_key
        }

        super().__init__(
            base_url=keys.immich_api_root_url,
            headers=headers
            )


    def get_random_image_ids(self, num=1) -> str:
        url = self.base_url + "album/" + keys.immich_album_id
        headers = self.headers | {"Accept": "application/json"}
        
        response = h.request("GET", url, headers=headers, data={})
        # raises an htppx exception if anything goes wrong
        if response.status_code == 200:
            response = json.loads(response.text)
        else:
            raise ImageGetException(f"Error in step get_random_image_id: {response.status_code}")

        images = response['assets']

        print(f"Picking {num} random id(s) out of {len(images)} album images")
        ids = []
        for i in range(num):
            image = random.choice(images)
            print(f"Image considered: {image['exifInfo']}")
            ids.append(image["id"])

        return ids


    def get_image_file(self, image_id: str) -> bytearray:
        url = self.base_url + "asset/download/" + image_id

        headers = self.headers | {"Accept": "application/octet-stream"}
        response = h.request("POST", url, headers=headers, data={})
        if not response.status_code == 200:
            raise ImageGetException("Error in step get_image_file: " + str(response.status_code))
            
        return response.content
